@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.*/
 
 /* GNU find was written by Eric Decker <cire@cisco.com>,
@@ -30,9 +30,9 @@
 #else
 #include <sys/file.h>
 #endif
-#include <human.h>
+#include "../gnulib/lib/human.h"
 #include <modetype.h>
-#include <savedir.h>
+#include "../gnulib/lib/savedir.h"
 
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
@@ -49,7 +49,8 @@
 #ifdef gettext_noop
 # define N_(String) gettext_noop (String)
 #else
-# define N_(String) (String)
+/* See locate.c for explanation as to why not use (String) */
+# define N_(String) String
 #endif
 
 #define apply_predicate(pathname, stat_buf_ptr, node)	\
@@ -316,7 +317,7 @@ main (int argc, char **argv)
   if (i == 1)
     process_top_path (".");
 
-  exit (exit_status);
+  return exit_status;
 }
 
 /* Safely go back to the starting directory. */
