@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.
 */
 
@@ -23,9 +23,9 @@
 #include <pwd.h>
 #include <grp.h>
 #include <fnmatch.h>
-#include "modechange.h"
+#include "../gnulib/lib/modechange.h"
 #include "modetype.h"
-#include "xstrtol.h"
+#include "../gnulib/lib/xstrtol.h"
 
 
 #if ENABLE_NLS
@@ -37,7 +37,8 @@
 #ifdef gettext_noop
 # define N_(String) gettext_noop (String)
 #else
-# define N_(String) (String)
+/* See locate.c for explanation as to why not use (String) */
+# define N_(String) String
 #endif
 
 #if !defined (isascii) || defined (STDC_HEADERS)
@@ -613,14 +614,17 @@ parse_ilname (char **argv, int *arg_ptr)
 static boolean 
 fnmatch_sanitycheck()
 {
+  /* fprintf(stderr, "Performing find sanity check..."); */
   if (0 != fnmatch("foo", "foo", 0)
       || 0 == fnmatch("Foo", "foo", 0)
       || 0 != fnmatch("Foo", "foo", FNM_CASEFOLD))
     {
       error (1, 0, _("sanity check of the fnmatch() library function failed."));
+      /* fprintf(stderr, "FAILED\n"); */
       return false;
     }
 
+  /* fprintf(stderr, "OK\n"); */
   return true;
 }
 
@@ -1679,14 +1683,21 @@ insert_time (char **argv, int *arg_ptr, PFB pred)
   t = ( cur_day_start - num_days * DAYSECS
 		   + ((c_type == COMP_GT) ? DAYSECS - 1 : 0));
 #if 1
-  intmax_t val = ( (intmax_t)cur_day_start - num_days * DAYSECS
-		   + ((c_type == COMP_GT) ? DAYSECS - 1 : 0));
-  t = val;
-  
-  /* Check for possibility of an overflow */
-  if ( (intmax_t)t != val ) 
+  if (1)
     {
-      error (1, 0, "arithmetic overflow while converting %s days to a number of seconds", argv[*arg_ptr]);
+      /* We introduce a scope in which 'val' can be declared, for the 
+       * benefit of compilers that are really C89 compilers
+       * which support intmax_t because config.h #defines it
+       */
+      intmax_t val = ( (intmax_t)cur_day_start - num_days * DAYSECS
+		       + ((c_type == COMP_GT) ? DAYSECS - 1 : 0));
+      t = val;
+      
+      /* Check for possibility of an overflow */
+      if ( (intmax_t)t != val ) 
+	{
+	  error (1, 0, "arithmetic overflow while converting %s days to a number of seconds", argv[*arg_ptr]);
+	}
     }
 #endif
   
