@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.
 */
 
@@ -24,8 +24,8 @@
 #include <signal.h>
 #include <pwd.h>
 #include <grp.h>
-#include "dirname.h"
-#include "human.h"
+#include "../gnulib/lib/dirname.h"
+#include "../gnulib/lib/human.h"
 #include "modetype.h"
 #include "wait.h"
 
@@ -38,7 +38,8 @@
 #ifdef gettext_noop
 # define N_(String) gettext_noop (String)
 #else
-# define N_(String) (String)
+/* See locate.c for explanation as to why not use (String) */
+# define N_(String) String
 #endif
 
 #if !defined(SIGCHLD) && defined(SIGCLD)
@@ -784,8 +785,11 @@ pred_iname (char *pathname, struct stat *stat_buf, struct predicate *pred_ptr)
 {
   const char *base;
 
+  /* FNM_PERIOD is not used here because POSIX requires that it not be.
+   * See http://standards.ieee.org/reading/ieee/interp/1003-2-92_int/pasc-1003.2-126.html
+   */
   base = base_name (pathname);
-  if (fnmatch (pred_ptr->args.str, base, FNM_PERIOD | FNM_CASEFOLD) == 0)
+  if (fnmatch (pred_ptr->args.str, base, FNM_CASEFOLD) == 0)
     return (true);
   return (false);
 }
@@ -925,7 +929,11 @@ pred_name (char *pathname, struct stat *stat_buf, struct predicate *pred_ptr)
   const char *base;
 
   base = base_name (pathname);
-  if (fnmatch (pred_ptr->args.str, base, FNM_PERIOD) == 0)
+
+  /* FNM_PERIOD is not used here because POSIX requires that it not be.
+   * See http://standards.ieee.org/reading/ieee/interp/1003-2-92_int/pasc-1003.2-126.html
+   */
+  if (fnmatch (pred_ptr->args.str, base, 0) == 0)
     return (true);
   return (false);
 }
