@@ -23,11 +23,6 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-# include <gnulib/config.h>
-# undef VERSION
-# undef PACKAGE_VERSION
-# undef PACKAGE_TARNAME
-# undef PACKAGE_STRING
 # include <config.h>
 #endif
 
