@@ -79,7 +79,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../../findutils.newgnulib/intl/plural.y"
+#line 1 "../../findutils/intl/plural.y"
 
 /* Expression parsing for plural form selection.
    Copyright (C) 2000, 2001 Free Software Foundation, Inc.
@@ -108,11 +108,6 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-# include <gnulib/config.h>
-# undef VERSION
-# undef PACKAGE_VERSION
-# undef PACKAGE_TARNAME
-# undef PACKAGE_STRING
 # include <config.h>
 #endif
 
@@ -148,14 +143,14 @@
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 57 "../../findutils.newgnulib/intl/plural.y"
+#line 52 "../../findutils/intl/plural.y"
 typedef union YYSTYPE {
   unsigned long int num;
   enum operator op;
   struct expression *exp;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 159 "plural.c"
+#line 154 "plural.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -164,7 +159,7 @@ typedef union YYSTYPE {
 
 
 /* Copy the second part of user declarations.  */
-#line 63 "../../findutils.newgnulib/intl/plural.y"
+#line 58 "../../findutils/intl/plural.y"
 
 /* Prototypes for local functions.  */
 static struct expression *new_exp PARAMS ((int nargs, enum operator op,
@@ -265,7 +260,7 @@ new_exp_3 (op, bexp, tbranch, fbranch)
 
 
 /* Line 214 of yacc.c.  */
-#line 269 "plural.c"
+#line 264 "plural.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -436,8 +431,8 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,   182,   182,   190,   194,   198,   202,   206,   210,   214,
-     218,   222,   226,   231
+       0,   177,   177,   185,   189,   193,   197,   201,   205,   209,
+     213,   217,   221,   226
 };
 #endif
 
@@ -1150,7 +1145,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 183 "../../findutils.newgnulib/intl/plural.y"
+#line 178 "../../findutils/intl/plural.y"
     {
 	    if (yyvsp[0].exp == NULL)
 	      YYABORT;
@@ -1159,70 +1154,70 @@ yyreduce:
     break;
 
   case 3:
-#line 191 "../../findutils.newgnulib/intl/plural.y"
+#line 186 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_3 (qmop, yyvsp[-4].exp, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 4:
-#line 195 "../../findutils.newgnulib/intl/plural.y"
+#line 190 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (lor, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 5:
-#line 199 "../../findutils.newgnulib/intl/plural.y"
+#line 194 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (land, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 6:
-#line 203 "../../findutils.newgnulib/intl/plural.y"
+#line 198 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 7:
-#line 207 "../../findutils.newgnulib/intl/plural.y"
+#line 202 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 8:
-#line 211 "../../findutils.newgnulib/intl/plural.y"
+#line 206 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 9:
-#line 215 "../../findutils.newgnulib/intl/plural.y"
+#line 210 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_2 (yyvsp[-1].op, yyvsp[-2].exp, yyvsp[0].exp);
 	  }
     break;
 
   case 10:
-#line 219 "../../findutils.newgnulib/intl/plural.y"
+#line 214 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_1 (lnot, yyvsp[0].exp);
 	  }
     break;
 
   case 11:
-#line 223 "../../findutils.newgnulib/intl/plural.y"
+#line 218 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = new_exp_0 (var);
 	  }
     break;
 
   case 12:
-#line 227 "../../findutils.newgnulib/intl/plural.y"
+#line 222 "../../findutils/intl/plural.y"
     {
 	    if ((yyval.exp = new_exp_0 (num)) != NULL)
 	      yyval.exp->val.num = yyvsp[0].num;
@@ -1230,7 +1225,7 @@ yyreduce:
     break;
 
   case 13:
-#line 232 "../../findutils.newgnulib/intl/plural.y"
+#line 227 "../../findutils/intl/plural.y"
     {
 	    yyval.exp = yyvsp[-1].exp;
 	  }
@@ -1240,7 +1235,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1244 "plural.c"
+#line 1239 "plural.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1434,7 +1429,7 @@ yyreturn:
 }
 
 
-#line 237 "../../findutils.newgnulib/intl/plural.y"
+#line 232 "../../findutils/intl/plural.y"
 
 
 void
