@@ -13,18 +13,11 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.
 */
 
 #if HAVE_CONFIG_H
-# include <gnulib/config.h>
-# undef VERSION
-# undef PACKAGE_VERSION
-# undef PACKAGE_TARNAME
-# undef PACKAGE_STRING
-# undef PACKAGE_NAME
-# undef PACKAGE
 # include <config.h>
 #endif
 
@@ -54,8 +47,8 @@ char *alloca ();
 #include <grp.h>
 #include <time.h>
 #include <errno.h>
-#include "human.h"
-#include "pathmax.h"
+#include "../gnulib/lib/human.h"
+#include "../gnulib/lib/pathmax.h"
 
 #if HAVE_STRING_H || STDC_HEADERS
 #include <string.h>
