@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.
 */
 
@@ -49,14 +49,6 @@
    Written by James A. Woods <jwoods@adobe.com>.
    Modified by David MacKenzie <djm@gnu.ai.mit.edu>.  */
 
-#define _GNU_SOURCE
-#include <gnulib/config.h>
-#undef VERSION
-#undef PACKAGE_VERSION
-#undef PACKAGE_TARNAME
-#undef PACKAGE_STRING
-#undef PACKAGE_NAME
-#undef PACKAGE
 #include <config.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -101,7 +93,11 @@ extern int errno;
 #ifdef gettext_noop
 # define N_(String) gettext_noop (String)
 #else
-# define N_(String) (String)
+/* We used to use (String) instead of just String, but HP-UX 11.23 for
+ * ia64 has what seems to be a compiler bug, because it refuses input
+ * like: static const char buf[] = ("string");i
+ */
+# define N_(String) String
 #endif
 
 #include "locatedb.h"
@@ -465,16 +461,14 @@ extern char *version_string;
 char *program_name;
 
 static void
-usage (stream, status)
+usage (stream)
      FILE *stream;
-     int status;
 {
   fprintf (stream, _("\
 Usage: %s [-d path | --database=path] [-e | --existing]\n\
       [-i | --ignore-case] [--version] [--help] pattern...\n"),
 	   program_name);
   fputs (_("\nReport bugs to <bug-findutils@gnu.org>.\n"), stream);
-  exit (status);
 }
 
 static struct option const longopts[] =
@@ -528,18 +522,24 @@ main (argc, argv)
 	break;
 	
       case 'h':
-	usage (stdout, 0);
+	usage (stdout);
+	return 0;
 
       case 'v':
 	printf (_("GNU locate version %s\n"), version_string);
-	exit (0);
+	return 0;
 
       default:
-	usage (stderr, 1);
+	usage (stderr);
+	return 1;
       }
 
   if (optind == argc)
-    usage (stderr, 1);
+    {
+      usage (stderr);
+      return 1;
+    }
+  
 
   for (; optind < argc; optind++)
     {
@@ -549,5 +549,8 @@ main (argc, argv)
 	found |= locate (argv[optind], e, ignore_case);
     }
 
-  exit (!found);
+  if (found)
+    return 0;
+  else
+    return 1;
 }
