@@ -13,20 +13,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 9 Temple Place - Suite 330, Boston, MA 02111-1307,
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.
 */
 
 /* Written by Mike Rendell <michael@cs.mun.ca>
    and David MacKenzie <djm@gnu.ai.mit.edu>.  */
 
-#include <gnulib/config.h>
-#undef VERSION
-#undef PACKAGE_VERSION
-#undef PACKAGE_TARNAME
-#undef PACKAGE_STRING
-#undef PACKAGE_NAME
-#undef PACKAGE
 #include <config.h>
 
 # ifndef PARAMS
@@ -133,7 +126,8 @@ extern int errno;
 #ifdef gettext_noop
 # define N_(String) gettext_noop (String)
 #else
-# define N_(String) (String)
+/* See locate.c for explanation as to why not use (String) */
+# define N_(String) String
 #endif
 
 /* Return nonzero if S is the EOF string.  */
@@ -295,7 +289,7 @@ static void add_proc PARAMS ((pid_t pid));
 static void wait_for_proc PARAMS ((boolean all));
 static long parse_num PARAMS ((char *str, int option, long min, long max));
 static long env_size PARAMS ((char **envp));
-static void usage PARAMS ((FILE * stream, int status));
+static void usage PARAMS ((FILE * stream));
 
 int
 main (int argc, char **argv)
@@ -347,7 +341,8 @@ main (int argc, char **argv)
 	  break;
 
 	case 'h':
-	  usage (stdout, 0);
+	  usage (stdout);
+	  return 0;
 
 	case 'i':
 	  if (optarg)
@@ -407,10 +402,11 @@ main (int argc, char **argv)
 
 	case 'v':
 	  printf (_("GNU xargs version %s\n"), version_string);
-	  exit (0);
+	  return 0;
 
 	default:
-	  usage (stderr, 1);
+	  usage (stderr);
+	  return 1;
 	}
     }
 
@@ -483,7 +479,7 @@ main (int argc, char **argv)
     }
 
   wait_for_proc (true);
-  exit (child_error);
+  return child_error;
 }
 
 #if 0
@@ -646,7 +642,7 @@ read_line (void)
 
 	case QUOTE:
 	  if (c == '\n')
-	    error (1, 0, _("unmatched %s quote"),
+	    error (1, 0, _("unmatched %s quote; by default quotes are special to xargs unless you use the -0 option"),
 		   quotc == '"' ? _("double") : _("single"));
 	  if (c == quotc)
 	    {
@@ -943,6 +939,7 @@ do_exec (void)
 	  execvp (cmd_argv[0], cmd_argv);
 	  error (0, errno, "%s", cmd_argv[0]);
 	  _exit (errno == ENOENT ? 127 : 126);
+	  /*NOTREACHED*/
 	}
       add_proc (child);
     }
@@ -1044,19 +1041,22 @@ parse_num (char *str, int option, long int min, long int max)
     {
       fprintf (stderr, _("%s: invalid number for -%c option\n"),
 	       program_name, option);
-      usage (stderr, 1);
+      usage (stderr);
+      exit(1);
     }
   else if (val < min)
     {
       fprintf (stderr, _("%s: value for -%c option must be >= %ld\n"),
 	       program_name, option, min);
-      usage (stderr, 1);
+      usage (stderr);
+      exit(1);
     }
   else if (max >= 0 && val > max)
     {
       fprintf (stderr, _("%s: value for -%c option must be < %ld\n"),
 	       program_name, option, max);
-      usage (stderr, 1);
+      usage (stderr);
+      exit(1);
     }
   return val;
 }
@@ -1075,7 +1075,7 @@ env_size (char **envp)
 }
 
 static void
-usage (FILE *stream, int status)
+usage (FILE *stream)
 {
   fprintf (stream, _("\
 Usage: %s [-0prtx] [-e[eof-str]] [-i[replace-str]] [-l[max-lines]]\n\
@@ -1086,5 +1086,4 @@ Usage: %s [-0prtx] [-e[eof-str]] [-i[replace-str]] [-l[max-lines]]\n\
        [command [initial-arguments]]\n"),
 	   program_name);
   fputs (_("\nReport bugs to <bug-findutils@gnu.org>.\n"), stream);
-  exit (status);
 }
